componenttools.iterate_components_forward_in_expr
=================================================

.. autofunction:: abjad.tools.componenttools.iterate_components_forward_in_expr.iterate_components_forward_in_expr
